More typo/spelling fixes

Francois Gouget fgouget at free.fr
Tue Jun 17 01:41:43 CDT 2003


Changelog:

   Typos/spelling fixes


Index: winedefault.reg
===================================================================
RCS file: /home/wine/wine/winedefault.reg,v
retrieving revision 1.74
diff -u -r1.74 winedefault.reg
--- winedefault.reg	16 Jun 2003 20:19:54 -0000	1.74
+++ winedefault.reg	17 Jun 2003 06:17:13 -0000
@@ -369,7 +369,7 @@
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{B196B28D-BAB4-101A-B69C-00AA00341D07}\ProxyStubClsid32]
 @="{B196B286-BAB4-101A-B69C-00AA00341D07}"

-#IPropertyPage2 - an extention of IPropertyPage to support initial selection on a property page
+#IPropertyPage2 - an extension of IPropertyPage to support initial selection on a property page
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{01E44665-24AC-101B-84ED-08002B2EC713}]
 @="IPropertyPage2"

@@ -449,7 +449,7 @@
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{376BD3AA-3845-101B-84ED-08002B2EC713}\ProxyStubClsid32]
 @="{B196B286-BAB4-101A-B69C-00AA00341D07}"

-#IAdviseSinkEx - an extention of IAdviseSink which provides notifications about object status changes
+#IAdviseSinkEx - an extension of IAdviseSink which provides notifications about object status changes
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{3AF24290-0C96-11CE-A0CF-00AA00600AB8}]
 @="IAdviseSinkEx"

@@ -589,7 +589,7 @@
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{B196B283-BAB4-101A-B69C-00AA00341D07}\ProxyStubClsid32]
 @="{B196B286-BAB4-101A-B69C-00AA00341D07}"

-#IProvideClassInfo2 - extention of class IProvideClassInfo
+#IProvideClassInfo2 - extension of class IProvideClassInfo
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{A6BC3AC0-DBAA-11CE-9DE3-00AA004BB851}]
 @="IProvideClassInfo2"

@@ -599,7 +599,7 @@
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{A6BC3AC0-DBAA-11CE-9DE3-00AA004BB851}\ProxyStubClsid32]
 @="{B196B286-BAB4-101A-B69C-00AA00341D07}"

-#IProvideMultipleClassInfo - an extention of IProvideClassInfo2 which can provide information about
+#IProvideMultipleClassInfo - an extension of IProvideClassInfo2 which can provide information about
 #a few implemented classes
 [HKEY_LOCAL_MACHINE\Software\Classes\Interface\{A7ABA9C1-8983-11CF-8F20-00805F2CD064}]
 @="IProvideMultipleClassInfo"
Index: dlls/cabinet/cabextract.c
===================================================================
RCS file: /home/wine/wine/dlls/cabinet/cabextract.c,v
retrieving revision 1.6
diff -u -r1.6 cabextract.c
--- dlls/cabinet/cabextract.c	17 Jun 2003 03:56:51 -0000	1.6
+++ dlls/cabinet/cabextract.c	17 Jun 2003 06:17:15 -0000
@@ -2009,7 +2009,7 @@
 	  case 17: foffset |= *p++ << 8;  state++; break;
 	  case 18: foffset |= *p++ << 16; state++; break;
 	  case 19: foffset |= *p++ << 24;
-	    /* now we have recieved 20 bytes of potential cab header. */
+	    /* now we have received 20 bytes of potential cab header. */
 	    /* work out the offset in the file of this potential cabinet */
 	    caboff = offset + (p-pstart) - 20;

Index: dlls/cabinet/fdi.c
===================================================================
RCS file: /home/wine/wine/dlls/cabinet/fdi.c,v
retrieving revision 1.6
diff -u -r1.6 fdi.c
--- dlls/cabinet/fdi.c	17 Jun 2003 03:56:51 -0000	1.6
+++ dlls/cabinet/fdi.c	17 Jun 2003 06:17:16 -0000
@@ -313,7 +313,7 @@
   num_folders = EndGetI16(buf+cfhead_NumFolders);
   if (num_folders == 0) {
     /* PONDERME: is this really invalid? */
-    WARN("wierd cabinet detect failure: no folders in cabinet\n");
+    WARN("weird cabinet detect failure: no folders in cabinet\n");
     PFDI_INT(hfdi)->perf->erfOper = FDIERROR_NOT_A_CABINET;
     PFDI_INT(hfdi)->perf->erfType = 0;
     PFDI_INT(hfdi)->perf->fError = TRUE;
@@ -324,7 +324,7 @@
   num_files = EndGetI16(buf+cfhead_NumFiles);
   if (num_files == 0) {
     /* PONDERME: is this really invalid? */
-    WARN("wierd cabinet detect failure: no files in cabinet\n");
+    WARN("weird cabinet detect failure: no files in cabinet\n");
     PFDI_INT(hfdi)->perf->erfOper = FDIERROR_NOT_A_CABINET;
     PFDI_INT(hfdi)->perf->erfType = 0;
     PFDI_INT(hfdi)->perf->fError = TRUE;
Index: dlls/comctl32/toolbar.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/toolbar.c,v
retrieving revision 1.133
diff -u -r1.133 toolbar.c
--- dlls/comctl32/toolbar.c	13 Jun 2003 16:30:24 -0000	1.133
+++ dlls/comctl32/toolbar.c	17 Jun 2003 06:17:21 -0000
@@ -1117,7 +1117,7 @@
 /***********************************************************************
 * 		TOOLBAR_WrapToolbar
 *
-* This function walks through the buttons and seperators in the
+* This function walks through the buttons and separators in the
 * toolbar, and sets the TBSTATE_WRAP flag only on those items where
 * wrapping should occur based on the width of the toolbar window.
 * It does *not* calculate button placement itself.  That task
Index: dlls/comctl32/updown.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/updown.c,v
retrieving revision 1.48
diff -u -r1.48 updown.c
--- dlls/comctl32/updown.c	2 Dec 2002 18:10:59 -0000	1.48
+++ dlls/comctl32/updown.c	17 Jun 2003 06:17:23 -0000
@@ -317,7 +317,7 @@
     len = wsprintfW(txt, fmt, infoPtr->CurVal);


-    /* Do thousands seperation if necessary */
+    /* Do thousands separation if necessary */
     if (!(GetWindowLongW (infoPtr->Self, GWL_STYLE) & UDS_NOTHOUSANDS) && (len > 3)) {
         WCHAR tmp[COUNT_OF(txt)], *src = tmp, *dst = txt;
         WCHAR sep = UPDOWN_GetThousandSep();
Index: dlls/commdlg/printdlg.c
===================================================================
RCS file: /home/wine/wine/dlls/commdlg/printdlg.c,v
retrieving revision 1.64
diff -u -r1.64 printdlg.c
--- dlls/commdlg/printdlg.c	14 May 2003 00:02:17 -0000	1.64
+++ dlls/commdlg/printdlg.c	17 Jun 2003 06:17:24 -0000
@@ -422,11 +422,11 @@
  *             PRINTDLG_UpdatePrintDlg          [internal]
  *
  *
- *   updates the PrintDlg structure for returnvalues.
+ *   updates the PrintDlg structure for return values.
  *
  * RETURNS
  *   FALSE if user is not allowed to close (i.e. wrong nTo or nFrom values)
- *   TRUE  if succesful.
+ *   TRUE  if successful.
  */
 static BOOL PRINTDLG_UpdatePrintDlgA(HWND hDlg,
 				    PRINT_PTRA* PrintStructures)
Index: dlls/d3d8/d3d8_private.h
===================================================================
RCS file: /home/wine/wine/dlls/d3d8/d3d8_private.h,v
retrieving revision 1.37
diff -u -r1.37 d3d8_private.h
--- dlls/d3d8/d3d8_private.h	13 Jun 2003 19:14:34 -0000	1.37
+++ dlls/d3d8/d3d8_private.h	17 Jun 2003 06:17:25 -0000
@@ -1289,7 +1289,7 @@
 /* Some #defines for additional diagnostics */
 #if 0 /* NOTE: Must be 0 in cvs */
   /* To avoid having to get gigabytes of trace, the following can be compiled in, and at the start
-     of each frame, a check is made for the existance of C:\D3DTRACE, and if if exists d3d trace
+     of each frame, a check is made for the existence of C:\D3DTRACE, and if if exists d3d trace
      is enabled, and if it doesnt exists it is disabled.                                           */
 # define FRAME_DEBUGGING
   /*  Adding in the SINGLE_FRAME_DEBUGGING gives a trace of just what makes up a single frame, before
Index: dlls/d3d8/device.c
===================================================================
RCS file: /home/wine/wine/dlls/d3d8/device.c,v
retrieving revision 1.72
diff -u -r1.72 device.c
--- dlls/d3d8/device.c	13 Jun 2003 19:14:34 -0000	1.72
+++ dlls/d3d8/device.c	17 Jun 2003 06:17:27 -0000
@@ -449,7 +449,7 @@
         object->surfaces[i]->myDesc.Usage = Usage;
         object->surfaces[i]->myDesc.Pool = Pool;
 	/**
-	 * As writen in msdn in IDirect3DTexture8::LockRect
+	 * As written in msdn in IDirect3DTexture8::LockRect
 	 *  Textures created in D3DPOOL_DEFAULT are not lockable.
 	 */
 	if (D3DPOOL_DEFAULT == Pool) {
@@ -596,7 +596,7 @@
            object->surfaces[j][i]->myDesc.Usage = Usage;
            object->surfaces[j][i]->myDesc.Pool = Pool;
 	   /**
-	    * As writen in msdn in IDirect3DCubeTexture8::LockRect
+	    * As written in msdn in IDirect3DCubeTexture8::LockRect
 	    *  Textures created in D3DPOOL_DEFAULT are not lockable.
 	    */
 	   if (D3DPOOL_DEFAULT == Pool) {
@@ -2235,7 +2235,7 @@
             /* Originally this used glLightModeli(GL_LIGHT_MODEL_COLOR_CONTROL,GL_SEPARATE_SPECULAR_COLOR)
                and (GL_LIGHT_MODEL_COLOR_CONTROL,GL_SINGLE_COLOR) to swap between enabled/disabled
                specular color. This is wrong:
-               Seperate specular color means the specular colour is maintained seperately, whereas
+               Separate specular color means the specular colour is maintained separately, whereas
                single color means it is merged in. However in both cases they are being used to
                some extent.
                To disable specular color, set it explicitly to black and turn off GL_COLOR_SUM_EXT
Index: dlls/dplayx/dplayx_global.c
===================================================================
RCS file: /home/wine/wine/dlls/dplayx/dplayx_global.c,v
retrieving revision 1.19
diff -u -r1.19 dplayx_global.c
--- dlls/dplayx/dplayx_global.c	7 Jan 2003 20:36:29 -0000	1.19
+++ dlls/dplayx/dplayx_global.c	17 Jun 2003 06:17:28 -0000
@@ -848,7 +848,7 @@
 {
   LPDPLAYX_LOBBYDATA lpDplData;

-  /* Paramater check */
+  /* Parameter check */
   if( dwFlags || !lpConn )
   {
     ERR("invalid parameters.\n");
@@ -912,7 +912,7 @@
 {
   LPDPLAYX_LOBBYDATA lpDplData;

-  /* Paramater check */
+  /* Parameter check */
   if( dwFlags || !lpConn )
   {
     ERR("invalid parameters.\n");
Index: dlls/kernel/tests/path.c
===================================================================
RCS file: /home/wine/wine/dlls/kernel/tests/path.c,v
retrieving revision 1.17
diff -u -r1.17 path.c
--- dlls/kernel/tests/path.c	13 May 2003 23:40:51 -0000	1.17
+++ dlls/kernel/tests/path.c	17 Jun 2003 06:17:31 -0000
@@ -183,7 +183,7 @@
   int len,i;
   len=lstrlenA(path);
   ext=len; fil=len; done=0; error=0;
-/* walk backwards over path looking for '.' or '\\' seperators */
+/* walk backwards over path looking for '.' or '\\' separators */
   for(i=len-1;(i>=0) && (!done);i--) {
     if(path[i]=='.')
       if(ext!=len) error=1; else ext=i;
Index: dlls/kernel/tests/thread.c
===================================================================
RCS file: /home/wine/wine/dlls/kernel/tests/thread.c,v
retrieving revision 1.9
diff -u -r1.9 thread.c
--- dlls/kernel/tests/thread.c	20 Jan 2003 23:26:09 -0000	1.9
+++ dlls/kernel/tests/thread.c	17 Jun 2003 06:17:32 -0000
@@ -537,10 +537,10 @@
      if (GetLastError()!=ERROR_CALL_NOT_IMPLEMENTED) {
        error=pSetThreadIdealProcessor(curthread,MAXIMUM_PROCESSORS+1);
        ok(error==-1,
-          "SetThreadIdealProccesor succeeded with an illegal processor #");
+          "SetThreadIdealProcessor succeeded with an illegal processor #");
        todo_wine {
          error=pSetThreadIdealProcessor(curthread,MAXIMUM_PROCESSORS);
-         ok(error==0, "SetThreadIdealProccesor returned an incorrect value");
+         ok(error==0, "SetThreadIdealProcessor returned an incorrect value");
        }
      }
    }
Index: dlls/ntdll/time.c
===================================================================
RCS file: /home/wine/wine/dlls/ntdll/time.c,v
retrieving revision 1.30
diff -u -r1.30 time.c
--- dlls/ntdll/time.c	2 Apr 2003 22:49:00 -0000	1.30
+++ dlls/ntdll/time.c	17 Jun 2003 06:17:33 -0000
@@ -505,7 +505,7 @@
  *
  * PARAMS
  *   time [I] Time to convert.
- *   res [O] Pointer to a LONG to recieve the seconds since 1970.
+ *   res [O] Pointer to a LONG to receive the seconds since 1970.
  *
  * RETURNS
  *   TRUE: Successfull.
@@ -528,7 +528,7 @@
  *
  * PARAMS
  *   time [I] Time to convert.
- *   res [O] Pointer to a integer to recieve the time since 1980.
+ *   res [O] Pointer to a integer to receive the time since 1980.
  *
  * RETURNS
  *   TRUE: Successfull
Index: dlls/ole32/antimoniker.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/antimoniker.c,v
retrieving revision 1.13
diff -u -r1.13 antimoniker.c
--- dlls/ole32/antimoniker.c	7 Jan 2003 20:36:28 -0000	1.13
+++ dlls/ole32/antimoniker.c	17 Jun 2003 06:17:34 -0000
@@ -264,7 +264,7 @@
     DWORD constant=1;
     HRESULT res;

-    /* data writen by this function is only a DWORD constant seted to 1 ! */
+    /* data written by this function is only a DWORD constant set to 1 ! */
     res=IStream_Write(pStm,&constant,sizeof(constant),NULL);

     return res;
Index: dlls/ole32/compobj.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/compobj.c,v
retrieving revision 1.77
diff -u -r1.77 compobj.c
--- dlls/ole32/compobj.c	17 Jun 2003 03:57:18 -0000	1.77
+++ dlls/ole32/compobj.c	17 Jun 2003 06:17:35 -0000
@@ -1281,7 +1281,7 @@

     TRACE("%s, %p\n", debugstr_w(filePathName), pclsid);

-    /* if the file contain a storage object the return the CLSID writen by IStorage_SetClass method*/
+    /* if the file contain a storage object the return the CLSID written by IStorage_SetClass method*/
     if((StgIsStorageFile(filePathName))==S_OK){

         res=StgOpenStorage(filePathName,NULL,STGM_READ | STGM_SHARE_DENY_WRITE,NULL,0,&pstg);
Index: dlls/ole32/compositemoniker.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/compositemoniker.c,v
retrieving revision 1.20
diff -u -r1.20 compositemoniker.c
--- dlls/ole32/compositemoniker.c	10 Apr 2003 18:17:35 -0000	1.20
+++ dlls/ole32/compositemoniker.c	17 Jun 2003 06:17:36 -0000
@@ -317,7 +317,7 @@

     /* this function call OleLoadFromStream function for each moniker within this object */

-    /* read the a constant writen by CompositeMonikerImpl_Save (see CompositeMonikerImpl_Save for more details)*/
+    /* read the a constant written by CompositeMonikerImpl_Save (see CompositeMonikerImpl_Save for more details)*/
     res=IStream_Read(pStm,&constant,sizeof(DWORD),NULL);

     if (SUCCEEDED(res)&& constant!=3)
Index: dlls/ole32/itemmoniker.c
===================================================================
RCS file: /home/wine/wine/dlls/ole32/itemmoniker.c,v
retrieving revision 1.17
diff -u -r1.17 itemmoniker.c
--- dlls/ole32/itemmoniker.c	7 Jan 2003 20:36:27 -0000	1.17
+++ dlls/ole32/itemmoniker.c	17 Jun 2003 06:17:36 -0000
@@ -323,7 +323,7 @@
     HRESULT res;
     CHAR *itemNameA,*itemDelimiterA;

-    /* data writen by this function are : 1) DWORD : size of item delimiter string ('\0' included ) */
+    /* data written by this function are : 1) DWORD : size of item delimiter string ('\0' included ) */
     /*                                    2) String (type A): item delimiter string ('\0' included)          */
     /*                                    3) DWORD : size of item name string ('\0' included)       */
     /*                                    4) String (type A): item name string ('\0' included)               */
Index: dlls/oleaut32/safearray.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/safearray.c,v
retrieving revision 1.25
diff -u -r1.25 safearray.c
--- dlls/oleaut32/safearray.c	13 Jun 2003 16:35:07 -0000	1.25
+++ dlls/oleaut32/safearray.c	17 Jun 2003 06:17:40 -0000
@@ -367,7 +367,7 @@
 {
   ULONG stepCountInSAData     = 0;    /* Number of array item to skip to get to
                                          the desired one... */
-  PVOID elementStorageAddress = NULL; /* Adress to store the data */
+  PVOID elementStorageAddress = NULL; /* Address to store the data */

   /* Validate the index given */
   if(! validCoordinate(rgIndices, psa))
@@ -415,7 +415,7 @@
     return E_UNEXPECTED; /* UNDOC error condition */
   }

-  TRACE("SafeArray: item put at adress %p.\n",elementStorageAddress);
+  TRACE("SafeArray: item put at address %p.\n",elementStorageAddress);
   return SafeArrayUnlock(psa);
 }

@@ -431,7 +431,7 @@
 {
   ULONG stepCountInSAData     = 0;    /* Number of array item to skip to get to
                                          the desired one... */
-  PVOID elementStorageAddress = NULL; /* Adress to store the data */
+  PVOID elementStorageAddress = NULL; /* Address to store the data */

   if(! validArg(psa))
     return E_INVALIDARG;
Index: dlls/shell32/shlexec.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlexec.c,v
retrieving revision 1.20
diff -u -r1.20 shlexec.c
--- dlls/shell32/shlexec.c	19 May 2003 23:07:49 -0000	1.20
+++ dlls/shell32/shlexec.c	17 Jun 2003 06:17:44 -0000
@@ -57,7 +57,7 @@
  *	%2 printer
  *	%3 driver
  *	%4 port
- * %I adress of a global item ID (explorer switch /idlist)
+ * %I address of a global item ID (explorer switch /idlist)
  * %L seems to be %1 as long filename followed by the 8+3 variation
  * %S ???
  * %* all following parameters (see batfile)
Index: dlls/shell32/shlfolder.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlfolder.c,v
retrieving revision 1.78
diff -u -r1.78 shlfolder.c
--- dlls/shell32/shlfolder.c	5 Mar 2003 02:48:26 -0000	1.78
+++ dlls/shell32/shlfolder.c	17 Jun 2003 06:17:44 -0000
@@ -49,7 +49,7 @@
 WINE_DEFAULT_DEBUG_CHANNEL (shell);

 /***************************************************************************
- * debughelper: print out the return adress
+ * debughelper: print out the return address
  *  helps especially to track down unbalanced AddRef/Release
  */
 #define MEM_DEBUG 0
Index: dlls/shell32/shlview.c
===================================================================
RCS file: /home/wine/wine/dlls/shell32/shlview.c,v
retrieving revision 1.77
diff -u -r1.77 shlview.c
--- dlls/shell32/shlview.c	19 May 2003 23:14:09 -0000	1.77
+++ dlls/shell32/shlview.c	17 Jun 2003 06:17:45 -0000
@@ -693,7 +693,7 @@
 	    mii.cbSize = sizeof(mii);
 	    mii.fMask = MIIM_TYPE | MIIM_ID | MIIM_STATE;

-	    if(TBSTYLE_SEP != Tools[i].bStyle) /* no seperator*/
+	    if(TBSTYLE_SEP != Tools[i].bStyle) /* no separator*/
 	    {
 	      mii.fType = MFT_STRING;
 	      mii.fState = MFS_ENABLED;
Index: dlls/shlwapi/clist.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/clist.c,v
retrieving revision 1.3
diff -u -r1.3 clist.c
--- dlls/shlwapi/clist.c	15 Mar 2003 19:40:11 -0000	1.3
+++ dlls/shlwapi/clist.c	17 Jun 2003 06:17:46 -0000
@@ -141,7 +141,7 @@
  *
  * PARAMS
  *  lpStream  [I] Stream to read the list from
- *  lppList   [0] Pointer to recieve the new List
+ *  lppList   [0] Pointer to receive the new List
  *
  * RETURNS
  *  Success: S_OK
Index: dlls/shlwapi/path.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/path.c,v
retrieving revision 1.32
diff -u -r1.32 path.c
--- dlls/shlwapi/path.c	13 May 2003 00:41:58 -0000	1.32
+++ dlls/shlwapi/path.c	17 Jun 2003 06:17:47 -0000
@@ -1426,7 +1426,7 @@
     return TRUE;
   }
   /* We have a root in the path */
-  lpszFile--; /* Start compacted filename with the path seperator */
+  lpszFile--; /* Start compacted filename with the path separator */
   dwFileLen++;

   if (dwFileLen + 3 > cchMax)
@@ -1776,7 +1776,7 @@
  *  FALSE Otherwise
  *
  * NOTES
- *  Multiple search masks may be given if they are seperated by ";". The
+ *  Multiple search masks may be given if they are separated by ";". The
  *  pattern "*.*" is treated specially in that it matches all paths (for
  *  backwards compatibility with DOS).
  */
Index: dlls/shlwapi/thread.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/thread.c,v
retrieving revision 1.9
diff -u -r1.9 thread.c
--- dlls/shlwapi/thread.c	2 Apr 2003 01:23:44 -0000	1.9
+++ dlls/shlwapi/thread.c	17 Jun 2003 06:17:47 -0000
@@ -104,7 +104,7 @@
  * Get an interface to the shell explorer.
  *
  * PARAMS
- *  lppUnknown [O] pointer to recieve IUnknown interface.
+ *  lppUnknown [O] pointer to receive IUnknown interface.
  *
  * RETURNS
  *  Success: S_OK. lppUnknown contains the explorer interface.
Index: dlls/winmm/wineoss/midi.c
===================================================================
RCS file: /home/wine/wine/dlls/winmm/wineoss/midi.c,v
retrieving revision 1.32
diff -u -r1.32 midi.c
--- dlls/winmm/wineoss/midi.c	6 May 2003 18:25:11 -0000	1.32
+++ dlls/winmm/wineoss/midi.c	17 Jun 2003 06:17:55 -0000
@@ -453,7 +453,7 @@
 }

 /**************************************************************************
- * 			midRecieveChar				[internal]
+ * 			midReceiveChar				[internal]
  */
 static void midReceiveChar(WORD wDevID, unsigned char value, DWORD dwTime)
 {
Index: documentation/HOWTO-winelib
===================================================================
RCS file: /home/wine/wine/documentation/HOWTO-winelib,v
retrieving revision 1.8
diff -u -r1.8 HOWTO-winelib
--- documentation/HOWTO-winelib	2 May 2003 20:08:53 -0000	1.8
+++ documentation/HOWTO-winelib	17 Jun 2003 06:18:11 -0000
@@ -422,7 +422,7 @@
 extern inline P_TEB WINAPI NtCurrentTeb(void);
 <<

-Those conversions are semanticaly the same as above but g++ compile
+Those conversions are semantically the same as above but g++ compile
 them and generate proper code to invoke __stdcall kind of functions

 in some of Wine/obj_XXX.h files: Wine/obj_base.h - there are a lot of
Index: documentation/PACKAGING
===================================================================
RCS file: /home/wine/wine/documentation/PACKAGING,v
retrieving revision 1.1
diff -u -r1.1 PACKAGING
--- documentation/PACKAGING	14 Apr 2003 21:31:49 -0000	1.1
+++ documentation/PACKAGING	17 Jun 2003 06:18:11 -0000
@@ -162,7 +162,7 @@
     * Shared Object Library Files
 	To obtain a current list of DLLs, run:
 		ls dlls/*.so
-	it the root of the Wine _build_ tree, after a sucessful build.
+	it the root of the Wine _build_ tree, after a successful build.

     * Man Pages
 	To obtain a current list of man files that need to be installed, run:
@@ -412,7 +412,7 @@
 	install -d $BR/etc/wine/
 	install -m 644 wine.ini $BR/etc/wine/wine.conf

-	# Put all our DLLs in a seperate directory. (this works only if you have a buildroot)
+	# Put all our DLLs in a separate directory. (this works only if you have a buildroot)
 	install -d $BR/usr/X11R6/lib/wine
 	mv $BR/usr/X11R6/lib/lib* $BR/usr/X11R6/lib/wine/

@@ -432,7 +432,7 @@
 	install -m 644 wine.userreg $BR/etc/wine/

 There are now a lot of libraries generated by the build process, so a
-seperate library directory should be used.
+separate library directory should be used.

 	install -d 755 $BR/usr/X11R6/lib/
 	mv $BR/
Index: documentation/debugger.sgml
===================================================================
RCS file: /home/wine/wine/documentation/debugger.sgml,v
retrieving revision 1.20
diff -u -r1.20 debugger.sgml
--- documentation/debugger.sgml	19 Apr 2003 02:50:57 -0000	1.20
+++ documentation/debugger.sgml	17 Jun 2003 06:18:13 -0000
@@ -1505,7 +1505,7 @@
       <sect2>
           <title>Debug channels</title>
 	      <para>
-               It is possible to turn on and off debug messages as you are debuging using
+               It is possible to turn on and off debug messages as you are debugging using
                the set command.
               </para>
             <screen>
Index: documentation/debugging.sgml
===================================================================
RCS file: /home/wine/wine/documentation/debugging.sgml,v
retrieving revision 1.9
diff -u -r1.9 debugging.sgml
--- documentation/debugging.sgml	4 Jun 2003 20:29:05 -0000	1.9
+++ documentation/debugging.sgml	17 Jun 2003 06:18:13 -0000
@@ -11,7 +11,7 @@
       <note>
         <para>
           It is possible to turn on and of debugging output from
-          within the debuger using the set command. Please see the
+          within the debugger using the set command. Please see the
           WineDbg Command Reference section for how to do this.
         </para>
       </note>
Index: documentation/dlls.sgml
===================================================================
RCS file: /home/wine/wine/documentation/dlls.sgml,v
retrieving revision 1.4
diff -u -r1.4 dlls.sgml
--- documentation/dlls.sgml	19 Apr 2003 02:50:57 -0000	1.4
+++ documentation/dlls.sgml	17 Jun 2003 06:18:13 -0000
@@ -50,7 +50,7 @@
           <title>2.1 Structure sizes of different common control versions</title>

           <para>
-            The common controls have been continously improved in the
+            The common controls have been continuously improved in the
             past. Some of the orignal structures had to be extended
             and their size changed. Most of the common control
             structures include their size as the first parameter. If a
Index: documentation/patches.sgml
===================================================================
RCS file: /home/wine/wine/documentation/patches.sgml,v
retrieving revision 1.8
diff -u -r1.8 patches.sgml
--- documentation/patches.sgml	19 Apr 2003 02:50:57 -0000	1.8
+++ documentation/patches.sgml	17 Jun 2003 06:18:14 -0000
@@ -145,10 +145,10 @@
         <title>Inline attachments with Outlook Express</title>
         <para>
           Outlook Express is notorious for mangleing attachements. Giving the
-          patch a <filename>.txt</filename> extention and attaching will solve
+          patch a <filename>.txt</filename> extension and attaching will solve
           the problem for most mailers including Outlook. Also, there is a way
           to enable Outlook Express send <filename>.diff</filename>
-          attachmnets.
+          attachments.
         </para>
         <para>
           You need following two things to make it work.
Index: documentation/shell32
===================================================================
RCS file: /home/wine/wine/documentation/shell32,v
retrieving revision 1.4
diff -u -r1.4 shell32
--- documentation/shell32	1 Jun 2000 23:25:45 -0000	1.4
+++ documentation/shell32	17 Jun 2003 06:18:14 -0000
@@ -17,10 +17,10 @@
   - many build-in icons are missing

 - shell notifications
-  - not aware of seperated addressspaces
+  - not aware of separated address spaces

 - iconcache
-  - not aware of seperated addressspaces
+  - not aware of separated address spaces
   - shell extensions

 - BrowseForFolder
Index: documentation/status/directplay
===================================================================
RCS file: /home/wine/wine/documentation/status/directplay,v
retrieving revision 1.10
diff -u -r1.10 directplay
--- documentation/status/directplay	26 Sep 2000 23:11:50 -0000	1.10
+++ documentation/status/directplay	17 Jun 2003 06:18:15 -0000
@@ -87,7 +87,7 @@
   - (done) Header files for DP4 and DPL3
   - (done) Add stub functions for all DP4 and DPL3 interfaces
   - (done) Correct naming of the parameters for DP3 and DPL2
-  - (done) Seperate out DP and DPL into multiple .c files
+  - (done) Separate out DP and DPL into multiple .c files
   - (done) Allow CoCreateInstance to create the new interfaces
   - (started)Implement mutual exclusion on object data for existing functions
   - (done) Create and move to correct dll directories (dplay and dplayx)
@@ -123,7 +123,7 @@
   - Need to implement lobby session spawning.

 ENHANCEMENTS:
-  - Improve footprint and realtime blocking by setting up a seperate data share
+  - Improve footprint and realtime blocking by setting up a separate data share
     between lobby application and client since there can be multiple apps per
     client. Also get rid of offset dependency by making data offset independent
     somehow.
Index: libs/wpp/ppl.l
===================================================================
RCS file: /home/wine/wine/libs/wpp/ppl.l,v
retrieving revision 1.2
diff -u -r1.2 ppl.l
--- libs/wpp/ppl.l	4 Jun 2003 20:25:55 -0000	1.2
+++ libs/wpp/ppl.l	17 Jun 2003 06:18:20 -0000
@@ -85,7 +85,7 @@
  * classical comment / *...* / (note: no comments within comments,
  * therefore spaces) is considered to be a line-continuation
  * (according to gcc and egcs AFAIK, ANSI is a bit vague).
- * Comments have not been added to the above grammer for simplicity
+ * Comments have not been added to the above grammar for simplicity
  * reasons. However, it is allowed to enter comment anywhere within
  * the directives as long as they do not interfere with the context.
  * All comments are considered to be deletable whitespace (both
@@ -1068,7 +1068,7 @@

 	/*
 	 * We must add *one* whitespace to make sure that there
-	 * is a token-seperation after the expansion.
+	 * is a token-separation after the expansion.
 	 */
 	*(++cptr) = ' ';
 	*(++cptr) = '\0';
Index: objects/font.c
===================================================================
RCS file: /home/wine/wine/objects/font.c,v
retrieving revision 1.98
diff -u -r1.98 font.c
--- objects/font.c	19 May 2003 23:24:30 -0000	1.98
+++ objects/font.c	17 Jun 2003 06:18:21 -0000
@@ -1945,7 +1945,7 @@
  *
  * RETURNS
  *
- *   The width and height of the string if succesful, 0 if failed.
+ *   The width and height of the string if successful, 0 if failed.
  *
  * BUGS
  *
Index: programs/notepad/main.c
===================================================================
RCS file: /home/wine/wine/programs/notepad/main.c,v
retrieving revision 1.26
diff -u -r1.26 main.c
--- programs/notepad/main.c	28 Jan 2003 01:10:28 -0000	1.26
+++ programs/notepad/main.c	17 Jun 2003 06:18:21 -0000
@@ -227,7 +227,7 @@
         }
         else
         {
-            /* try to find file with ".txt" extention */
+            /* try to find file with ".txt" extension */
             if (!strcmp(".txt", cmdline + strlen(cmdline) - strlen(".txt")))
             {
                 file_exists = FALSE;
Index: programs/view/view.c
===================================================================
RCS file: /home/wine/wine/programs/view/view.c,v
retrieving revision 1.8
diff -u -r1.8 view.c
--- programs/view/view.c	19 May 2003 23:16:55 -0000	1.8
+++ programs/view/view.c	17 Jun 2003 06:18:22 -0000
@@ -144,7 +144,7 @@
       PostQuitMessage(0);
       break;

-    default:          /* Passes it on if unproccessed */
+    default:          /* Passes it on if unprocessed */
       return DefWindowProc(hwnd, uMessage, wparam, lparam);
     }
     return 0;
Index: programs/winecfg/main.c
===================================================================
RCS file: /home/wine/wine/programs/winecfg/main.c,v
retrieving revision 1.1
diff -u -r1.1 main.c
--- programs/winecfg/main.c	31 Mar 2003 19:41:55 -0000	1.1
+++ programs/winecfg/main.c	17 Jun 2003 06:18:22 -0000
@@ -257,7 +257,7 @@
 /*****************************************************************************
  * Name       : WinMain
  * Description: Main windows entry point
- * Paramaters : hInstance
+ * Parameters : hInstance
  *              hPrev
  *              szCmdLine
  *              nShow
Index: programs/winecfg/winecfg.rc
===================================================================
RCS file: /home/wine/wine/programs/winecfg/winecfg.rc,v
retrieving revision 1.1
diff -u -r1.1 winecfg.rc
--- programs/winecfg/winecfg.rc	31 Mar 2003 19:41:55 -0000	1.1
+++ programs/winecfg/winecfg.rc	17 Jun 2003 06:18:22 -0000
@@ -71,9 +71,9 @@
                     BS_AUTOCHECKBOX | WS_TABSTOP,17,62,91,10
     CONTROL         "Favor correctness over speed",IDC_PERFECTGRAPH,"Button",
                     BS_AUTOCHECKBOX | WS_TABSTOP,17,76,117,10
-    CONTROL         "Use XFree DGA extention",IDC_XDGA,"Button",
+    CONTROL         "Use XFree DGA extension",IDC_XDGA,"Button",
                     BS_AUTOCHECKBOX | WS_TABSTOP,141,62,97,10
-    CONTROL         "Use XFree Shm extention",IDC_XSHM,"Button",
+    CONTROL         "Use XFree Shm extension",IDC_XSHM,"Button",
                     BS_AUTOCHECKBOX | WS_TABSTOP,141,76,96,10
     CONTROL         "Enable Wine desktop",IDC_MANAGED,"Button",
                     BS_AUTOCHECKBOX | WS_TABSTOP,17,143,84,10
Index: programs/winedbg/registers.c
===================================================================
RCS file: /home/wine/wine/programs/winedbg/registers.c,v
retrieving revision 1.1
diff -u -r1.1 registers.c
--- programs/winedbg/registers.c	13 Sep 2002 17:54:28 -0000	1.1
+++ programs/winedbg/registers.c	17 Jun 2003 06:18:23 -0000
@@ -59,9 +59,9 @@
     if ( buf >= pt-- ) return( buf );
     if ( flag & 0x00000800 ) *pt = 'O'; /* Overflow Flag */
     if ( buf >= pt-- ) return( buf );
-    if ( flag & 0x00001000 ) *pt = '1'; /* I/O Privilage Level */
+    if ( flag & 0x00001000 ) *pt = '1'; /* I/O Privilege Level */
     if ( buf >= pt-- ) return( buf );
-    if ( flag & 0x00002000 ) *pt = '1'; /* I/O Privilage Level */
+    if ( flag & 0x00002000 ) *pt = '1'; /* I/O Privilege Level */
     if ( buf >= pt-- ) return( buf );
     if ( flag & 0x00004000 ) *pt = 'N'; /* Nested Task Flag */
     if ( buf >= pt-- ) return( buf );
Index: tools/winedump/README
===================================================================
RCS file: /home/wine/wine/tools/winedump/README,v
retrieving revision 1.4
diff -u -r1.4 README
--- tools/winedump/README	20 Sep 2002 19:19:34 -0000	1.4
+++ tools/winedump/README	17 Jun 2003 06:18:28 -0000
@@ -203,7 +203,7 @@

 Your application can now link with the DLL.

-If you recieve the following error when running autoconf:
+If you receive the following error when running autoconf:

  autoconf: configure.in: No such file or directory

@@ -466,13 +466,13 @@
 by value, its size also needs to be correct in order to forward the call
 correctly to a native DLL. In this case the structure is 8 bytes in size, which
 means that the gcc compile flag -freg-struct-return must be given when
-compiling the function in order to be compatable with the native DLL. (In
+compiling the function in order to be compatible with the native DLL. (In
 general this is not an issue, but you need to be aware of such issues if you
 encounter problems with your forwarding DLL).

 For third party (non C++) DLL's, the header(s) supplied with the DLL  can
 normally be added as an include to the generated DLL header. For other DLLs
-I suggest creating a seperate header in the DLL directory and adding any
+I suggest creating a separate header in the DLL directory and adding any
 needed types to that. This allows you to rebuild the DLL at whim, for example
 if a new version of winedump brings increased functionality, then you
 only have to overwrite the generated files and re-include the header to take
@@ -551,14 +551,14 @@
 the native (Win32) ms_msvcrt.dll. Add the following two lines to ~/.wine/config
 under the [DllOverrides] section:

-;Use our implmentation of msvcrt
+;Use our implementation of msvcrt
 "msvcrt" = "builtin, so"
 ;Use only the Win32 ms_msvcrt
 "ms_msvcrt" = "native"

-At this point, when any call is made to msvcrt.dll, Our libmsvcrt.so recieves
+At this point, when any call is made to msvcrt.dll, Our libmsvcrt.so receives
 the call. It then forwards or calls ms_msvcrt.dll, which is the native dll. We
-recieve a return value and pass it back to our caller, having TRACEd the
+receive a return value and pass it back to our caller, having TRACEd the
 arguments on the way.

 At this point you are ready to start reimplementing the calls.
Index: tools/wrc/parser.y
===================================================================
RCS file: /home/wine/wine/tools/wrc/parser.y,v
retrieving revision 1.36
diff -u -r1.36 parser.y
--- tools/wrc/parser.y	1 May 2003 03:16:21 -0000	1.36
+++ tools/wrc/parser.y	17 Jun 2003 06:18:29 -0000
@@ -84,7 +84,7 @@
  *			- Parser now emits a warning when compiling win32
  *			  extensions in win16 mode.
  *
- * 16-Apr-1998 BS	- Raw data elements are now *optionally* seperated
+ * 16-Apr-1998 BS	- Raw data elements are now *optionally* separated
  *			  by commas. Read the comments in file sq2dq.l.
  *			- FIXME: there are instances in the source that rely
  *			  on the fact that int==32bit and pointers are int size.



Index: dlls/oleaut32/variant.c
===================================================================
RCS file: /home/wine/wine/dlls/oleaut32/variant.c,v
retrieving revision 1.63
diff -u -r1.63 variant.c
--- dlls/oleaut32/variant.c	17 May 2003 18:30:03 -0000	1.63
+++ dlls/oleaut32/variant.c	17 Jun 2003 06:17:42 -0000
@@ -4489,7 +4489,7 @@

 /**********************************************************************
  *              VarCyFromStr [OLEAUT32.104]
  * FIXME: Never tested with decimal seperator other than '.'
  */
 HRESULT WINAPI VarCyFromStr(OLECHAR *strIn, LCID lcid, ULONG dwFlags, CY *pcyOut) {

@@ -4503,19 +4503,19 @@
 	pNewString = HEAP_strdupWtoA( GetProcessHeap(), 0, strIn );
 	TRACE("( '%s', 0x%08lx, 0x%08lx, %p )\n", pNewString, lcid, dwFlags, pcyOut );

     /* Get locale information - Decimal Seperator (size includes 0x00) */
     size = GetLocaleInfoA(lcid, LOCALE_SDECIMAL, NULL, 0);
     decSep = (char *) malloc(size);
     rc = GetLocaleInfoA(lcid, LOCALE_SDECIMAL, decSep, size);
-    TRACE("Decimal Seperator is '%s'\n", decSep);
+    TRACE("Decimal Separator is '%s'\n", decSep);

     /* Now copy to temporary buffer, skipping any character except 0-9 and
-       the decimal seperator */
+       the decimal separator */
     curPtr = pBuffer;      /* Current position in string being built       */
     strPtr = pNewString;   /* Current position in supplied currenct string */

     while (*strPtr) {
         /* If decimal seperator, skip it and put '.' in string */
         if (strncmp(strPtr, decSep, (size-1)) == 0) {
             strPtr = strPtr + (size-1);
             *curPtr = '.';
@@ -5961,19 +5961,19 @@
             break;

         case TOK_COLON   :
             /* Get locale information - Time Seperator */
             size = GetLocaleInfoA(lcid, LOCALE_STIME, NULL, 0);
             GetLocaleInfoA(lcid, LOCALE_STIME, pNextPos, size);
-            TRACE("TOK_COLON Time seperator is '%s'\n", pNextPos);
+            TRACE("TOK_COLON Time separator is '%s'\n", pNextPos);
             pNextPos = pNextPos + size;
             pData = pData + 1;
             break;

         case TOK_SLASH   :
             /* Get locale information - Date Seperator */
             size = GetLocaleInfoA(lcid, LOCALE_SDATE, NULL, 0);
             GetLocaleInfoA(lcid, LOCALE_SDATE, pNextPos, size);
-            TRACE("TOK_COLON Time seperator is '%s'\n", pNextPos);
+            TRACE("TOK_COLON Time separator is '%s'\n", pNextPos);
             pNextPos = pNextPos + size;
             pData = pData + 1;
             break;
@@ -4489,7 +4489,7 @@
 /**********************************************************************
  *              VarCyFromStr [OLEAUT32.104]
- * FIXME: Never tested with decimal seperator other than '.'
+ * FIXME: Never tested with decimal separator other than '.'
  */
 HRESULT WINAPI VarCyFromStr(OLECHAR *strIn, LCID lcid, ULONG dwFlags, CY *pcyOut) {
@@ -4503,19 +4503,19 @@
 	TRACE("( '%s', 0x%08lx, 0x%08lx, %p )\n", pNewString, lcid, dwFlags, pcyOut );

-    /* Get locale information - Decimal Seperator (size includes 0x00) */
+    /* Get locale information - Decimal Separator (size includes 0x00) */
     size = GetLocaleInfoA(lcid, LOCALE_SDECIMAL, NULL, 0);
     decSep = (char *) malloc(size);
@@ -4503,19 +4503,19 @@

     while (*strPtr) {
-        /* If decimal seperator, skip it and put '.' in string */
+        /* If decimal separator, skip it and put '.' in string */
         if (strncmp(strPtr, decSep, (size-1)) == 0) {
             strPtr = strPtr + (size-1);
@@ -5961,19 +5961,19 @@

         case TOK_COLON   :
-            /* Get locale information - Time Seperator */
+            /* Get locale information - Time Separator */
             size = GetLocaleInfoA(lcid, LOCALE_STIME, NULL, 0);
             GetLocaleInfoA(lcid, LOCALE_STIME, pNextPos, size);
@@ -5961,19 +5961,19 @@

         case TOK_SLASH   :
-            /* Get locale information - Date Seperator */
+            /* Get locale information - Date Separator */
             size = GetLocaleInfoA(lcid, LOCALE_SDATE, NULL, 0);
             GetLocaleInfoA(lcid, LOCALE_SDATE, pNextPos, size);
-- 
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
  Any sufficiently advanced Operating System is indistinguishable from Linux




More information about the wine-patches mailing list